==========
*pyrelist*
==========

.. image:: https://img.shields.io/pypi/v/pyrelist

.. image:: https://img.shields.io/github/license/veltzer/pyrelist

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pyrelist

author: Mark Veltzer

version: 0.0.3

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2024
